<?php
// 确保中文正常显示
header('Content-Type: text/html; charset=utf-8');

// 定义数据文件路径
$alarmsFile = 'alarms.txt';

// 处理添加闹钟请求
if (isset($_POST['add_alarm'])) {
    $time = $_POST['alarm_time'];
    $sound = $_POST['alarm_sound'];
    $label = $_POST['alarm_label'];
    
    // 创建闹钟数据
    $alarmData = [
        'time' => $time,
        'sound' => $sound,
        'label' => $label,
        'added_at' => date('Y-m-d H:i:s'),
        'triggered' => false, // 未触发状态
        'date' => date('Y-m-d') // 添加日期标记，用于判断是否为当天闹钟
    ];
    
    // 写入文件
    file_put_contents($alarmsFile, json_encode($alarmData) . PHP_EOL, FILE_APPEND);
    
    // 重定向以避免重复提交
    header('Location: index.php');
    exit;
}

// 处理删除闹钟请求
if (isset($_GET['delete_alarm'])) {
    $index = $_GET['delete_alarm'];
    
    // 读取所有闹钟
    $alarms = file($alarmsFile, FILE_IGNORE_NEW_LINES);
    
    // 删除指定闹钟
    if (isset($alarms[$index])) {
        unset($alarms[$index]);
        $alarms = array_values($alarms);
        
        // 重写文件
        file_put_contents($alarmsFile, implode(PHP_EOL, $alarms));
    }
    
    // 重定向以避免重复提交
    header('Location: index.php');
    exit;
}

// 获取当前时间（用于显示）
$currentTime = date('H:i:s');
$currentDate = date('Y-m-d');
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>多功能时钟应用</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link href="https://cdn.jsdelivr.net/npm/font-awesome@4.7.0/css/font-awesome.min.css" rel="stylesheet">
    
    <!-- Tailwind CSS 配置 -->
    <script>
        tailwind.config = {
            theme: {
                extend: {
                    colors: {
                        primary: '#165DFF',
                        secondary: '#FF7D00',
                        accent: '#722ED1',
                        dark: '#1D2129',
                        light: '#F2F3F5',
                        danger: '#F53F3F'
                    },
                    fontFamily: {
                        inter: ['Inter', 'sans-serif'],
                    },
                }
            }
        }
    </script>
    
    <!-- 自定义工具类 -->
    <style type="text/tailwindcss">
        @layer utilities {
            .content-auto {
                content-visibility: auto;
            }
            .clock-shadow {
                box-shadow: 0 10px 25px -5px rgba(22, 93, 255, 0.1), 0 8px 10px -6px rgba(22, 93, 255, 0.1);
            }
            .timer-circle {
                background: conic-gradient(#165DFF var(--progress), #F2F3F5 0);
            }
            .alarm-pulse {
                animation: alarmPulse 1s infinite;
            }
        }
    </style>
    
    <style>
        /* 导入Inter字体 */
        @import url('https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap');
        
        body {
            font-family: 'Inter', sans-serif;
        }
        
        /* 时钟数字动画 */
        @keyframes digital-clock {
            0% { transform: translateY(0); }
            100% { transform: translateY(-100%); }
        }
        
        .clock-digit {
            transition: all 0.5s ease;
        }
        
        /* 秒表数字动画 */
        .stopwatch-digit {
            transition: all 0.2s ease;
        }
        
        /* 计时器倒计时动画 */
        @keyframes pulse {
            0%, 100% { transform: scale(1); }
            50% { transform: scale(1.05); }
        }
        
        .timer-pulse {
            animation: pulse 1s infinite;
        }
        
        /* 闹钟触发动画 */
        @keyframes alarm-ring {
            0%, 100% { transform: translateX(0); }
            25% { transform: translateX(-10px); }
            75% { transform: translateX(10px); }
        }
        
        @keyframes alarmPulse {
            0%, 100% { background-color: #F53F3F; }
            50% { background-color: #FF7D00; }
        }
        
        .alarm-ringing {
            animation: alarm-ring 0.2s infinite;
        }
        
        /* 确保计时器数字显示在进度环上方 */
        #timer-display {
            position: relative;
            z-index: 10;
        }
        
        #timer-progress {
            position: absolute;
            inset: 0;
            border-radius: 50%;
            background: conic-gradient(#165DFF var(--progress), #F2F3F5 0);
            z-index: 5;
            opacity: 0.3;
        }
        
        /* 闹钟项悬停效果优化 */
        .alarm-item {
            transition: all 0.3s ease;
        }
        
        .alarm-item:hover {
            transform: translateY(-3px);
            box-shadow: 0 10px 25px -5px rgba(22, 93, 255, 0.15);
        }
    </style>
</head>
<body class="bg-gradient-to-br from-light to-gray-200 min-h-screen">
    <div class="container mx-auto px-4 py-8 max-w-6xl">
        <!-- 页面标题 -->
        <header class="text-center mb-8">
            <h1 class="text-[clamp(2rem,5vw,3.5rem)] font-bold text-dark mb-2">多功能时钟</h1>
            <p class="text-gray-500 text-lg">集成闹钟、秒表和计时器功能</p>
        </header>
        
        <!-- 主导航 -->
        <nav class="mb-8">
            <div class="flex flex-wrap justify-center gap-4">
                <button id="nav-alarm" class="nav-btn active px-6 py-3 rounded-full bg-primary text-white shadow-lg hover:bg-primary/90 transition-all duration-300 flex items-center">
                    <i class="fa fa-bell mr-2"></i> 闹钟
                </button>
                <button id="nav-stopwatch" class="nav-btn px-6 py-3 rounded-full bg-white text-dark shadow-md hover:bg-gray-50 transition-all duration-300 flex items-center">
                    <i class="fa fa-clock-o mr-2"></i> 秒表
                </button>
                <button id="nav-timer" class="nav-btn px-6 py-3 rounded-full bg-white text-dark shadow-md hover:bg-gray-50 transition-all duration-300 flex items-center">
                    <i class="fa fa-hourglass-half mr-2"></i> 计时器
                </button>
            </div>
        </nav>
        
        <!-- 主内容区 -->
        <main>
            <!-- 闹钟功能 -->
            <section id="alarm-section" class="active">
                <!-- 当前时间显示 -->
                <div class="bg-white rounded-2xl p-6 mb-8 clock-shadow">
                    <div class="flex flex-col items-center">
                        <div class="text-2xl text-gray-500 mb-2">当前时间</div>
                        <div id="current-time" class="text-[clamp(2.5rem,8vw,5rem)] font-bold text-dark tracking-wider">
                            <?php echo $currentTime; ?>
                        </div>
                        <div class="text-lg text-gray-500 mt-2" id="current-date"><?php echo date('Y年m月d日 l'); ?></div>
                    </div>
                </div>
                
                <!-- 闹钟列表 -->
                <div class="bg-white rounded-2xl p-6 mb-8 clock-shadow">
                    <div class="flex justify-between items-center mb-6">
                        <h2 class="text-2xl font-bold text-dark">我的闹钟</h2>
                        <button id="add-alarm-btn" class="bg-primary text-white px-4 py-2 rounded-lg hover:bg-primary/90 transition-all duration-300 flex items-center">
                            <i class="fa fa-plus mr-2"></i> 添加闹钟
                        </button>
                    </div>
                    
                    <div id="alarms-container" class="space-y-4">
                        <?php
                        // 读取并显示闹钟
                        if (file_exists($alarmsFile) && filesize($alarmsFile) > 0) {
                            $alarms = file($alarmsFile, FILE_IGNORE_NEW_LINES);
                            $index = 0;
                            $hasAlarms = false;
                            
                            foreach ($alarms as $alarm) {
                                $alarmData = json_decode($alarm, true);
                                $time = $alarmData['time'];
                                $sound = $alarmData['sound'];
                                $label = $alarmData['label'];
                                $date = $alarmData['date'];
                                $triggered = $alarmData['triggered'];
                                
                                // 检查是否为今天的闹钟（未触发）
                                $isTodayAlarm = ($date === $currentDate && !$triggered);
                                
                                // 构建闹钟项样式
                                $alarmClass = 'alarm-item bg-light rounded-xl p-4 flex justify-between items-center transition-all duration-300 hover:shadow-md';
                                if ($isTodayAlarm) {
                                    $alarmClass .= ' border-l-4 border-primary';
                                } else if ($triggered) {
                                    $alarmClass .= ' bg-gray-100 opacity-70';
                                }
                                
                                echo '<div class="' . $alarmClass . '" data-index="' . $index . '">';
                                echo '<div class="flex items-center">';
                                echo '<div class="mr-4 text-2xl font-semibold' . ($isTodayAlarm ? ' text-primary' : '') . '">' . $time . '</div>';
                                echo '<div>';
                                echo '<div class="font-medium' . ($isTodayAlarm ? ' text-primary' : '') . '">' . htmlspecialchars($label) . '</div>';
                                echo '<div class="text-sm text-gray-500">声音: ' . htmlspecialchars($sound) . '</div>';
                                if ($date !== $currentDate && !$triggered) {
                                    echo '<div class="text-xs text-gray-400 mt-1">日期: ' . date('m月d日', strtotime($date)) . '</div>';
                                }
                                echo '</div>';
                                echo '</div>';
                                echo '<button class="delete-alarm-btn text-gray-400 hover:text-danger transition-colors" data-index="' . $index . '">';
                                echo '<i class="fa fa-trash-o text-xl"></i>';
                                echo '</button>';
                                echo '</div>';
                                
                                $hasAlarms = true;
                                $index++;
                            }
                            
                            if (!$hasAlarms) {
                                echo '<div class="text-center py-8 text-gray-500">';
                                echo '<i class="fa fa-bell-o text-4xl mb-4"></i>';
                                echo '<p>暂无闹钟，请添加新闹钟</p>';
                                echo '</div>';
                            }
                        } else {
                            echo '<div class="text-center py-8 text-gray-500">';
                            echo '<i class="fa fa-bell-o text-4xl mb-4"></i>';
                            echo '<p>暂无闹钟，请添加新闹钟</p>';
                            echo '</div>';
                        }
                        ?>
                    </div>
                </div>
            </section>
            
            <!-- 添加闹钟表单 (默认隐藏) -->
            <section id="add-alarm-section" class="hidden">
                <div class="bg-white rounded-2xl p-6 mb-8 clock-shadow">
                    <div class="flex justify-between items-center mb-6">
                        <h2 class="text-2xl font-bold text-dark">添加闹钟</h2>
                        <button id="back-to-alarms-btn" class="text-gray-400 hover:text-gray-600 transition-colors">
                            <i class="fa fa-arrow-left text-xl"></i>
                        </button>
                    </div>
                    
                    <form id="add-alarm-form" method="post">
                        <div class="space-y-6">
                            <div>
                                <label for="alarm-time" class="block text-sm font-medium text-gray-700 mb-1">闹钟时间</label>
                                <input type="time" id="alarm-time" name="alarm_time" class="w-full p-3 rounded-lg border border-gray-300 focus:ring-2 focus:ring-primary focus:border-primary transition-all duration-300" required>
                            </div>
                            
                            <div>
                                <label for="alarm-label" class="block text-sm font-medium text-gray-700 mb-1">闹钟标签</label>
                                <input type="text" id="alarm-label" name="alarm_label" placeholder="例如: 起床、会议提醒" class="w-full p-3 rounded-lg border border-gray-300 focus:ring-2 focus:ring-primary focus:border-primary transition-all duration-300" required>
                            </div>
                            
                            <div>
                                <label for="alarm-sound" class="block text-sm font-medium text-gray-700 mb-1">闹钟声音</label>
                                <input type="text" id="alarm-sound" name="alarm_sound" placeholder="输入音乐链接" class="w-full p-3 rounded-lg border border-gray-300 focus:ring-2 focus:ring-primary focus:border-primary transition-all duration-300" required value="/铃声.mp3">
                                <p class="text-xs text-gray-500 mt-1">请输入有效的音乐链接，例如: https://example.com/alarm.mp3</p>
                            </div>
                            
                            <div class="flex justify-end">
                                <button type="submit" name="add_alarm" class="bg-primary text-white px-6 py-3 rounded-lg hover:bg-primary/90 transition-all duration-300 flex items-center">
                                    <i class="fa fa-check mr-2"></i> 保存闹钟
                                </button>
                            </div>
                        </div>
                    </form>
                </div>
            </section>
            
            <!-- 秒表功能 -->
            <section id="stopwatch-section" class="hidden">
                <div class="bg-white rounded-2xl p-6 mb-8 clock-shadow">
                    <div class="flex flex-col items-center">
                        <div class="text-2xl text-gray-500 mb-2">秒表</div>
                        <div id="stopwatch-display" class="text-[clamp(2.5rem,8vw,5rem)] font-bold text-dark tracking-wider">
                            00:00:00
                        </div>
                        
                        <div class="flex gap-4 mt-8">
                            <button id="start-stopwatch" class="bg-primary text-white px-6 py-3 rounded-lg hover:bg-primary/90 transition-all duration-300 flex items-center">
                                <i class="fa fa-play mr-2"></i> 开始
                            </button>
                            <button id="stop-stopwatch" class="bg-gray-200 text-gray-700 px-6 py-3 rounded-lg hover:bg-gray-300 transition-all duration-300 flex items-center" disabled>
                                <i class="fa fa-pause mr-2"></i> 停止
                            </button>
                            <button id="reset-stopwatch" class="bg-gray-200 text-gray-700 px-6 py-3 rounded-lg hover:bg-gray-300 transition-all duration-300 flex items-center" disabled>
                                <i class="fa fa-refresh mr-2"></i> 重置
                            </button>
                        </div>
                    </div>
                </div>
                
                <div class="bg-white rounded-2xl p-6 clock-shadow">
                    <h2 class="text-xl font-bold text-dark mb-4">计时记录</h2>
                    <div id="stopwatch-laps" class="space-y-2 max-h-64 overflow-yauto">
                        <div class="text-center py-8 text-gray-500">
                            <i class="fa fa-clock-o text-4xl mb-4"></i>
                            <p>暂无计时记录</p>
                        </div>
                    </div>
                    <div class="mt-4">
                        <button id="lap-stopwatch" class="bg-gray-200 text-gray-700 px-4 py-2 rounded-lg hover:bg-gray-300 transition-all duration-300 flex items-center" disabled>
                            <i class="fa fa-flag mr-2"></i> 计次
                        </button>
                    </div>
                </div>
            </section>
            
            <!-- 计时器功能 -->
            <section id="timer-section" class="hidden">
                <div class="bg-white rounded-2xl p-6 mb-8 clock-shadow">
                    <div class="flex flex-col items-center">
                        <div class="text-2xl text-gray-500 mb-2">计时器</div>
                        
                        <!-- 计时器设置 -->
                        <div id="timer-settings" class="flex gap-4 mb-8">
                            <div class="text-center">
                                <input type="number" id="timer-hours" min="0" max="23" value="0" class="w-20 h-20 text-4xl font-bold text-center border border-gray-300 rounded-lg focus:ring-2 focus:ring-primary focus:border-primary transition-all duration-300">
                                <div class="text-sm text-gray-500 mt-1">小时</div>
                            </div>
                            <div class="text-center">
                                <input type="number" id="timer-minutes" min="0" max="59" value="0" class="w-20 h-20 text-4xl font-bold text-center border border-gray-300 rounded-lg focus:ring-2 focus:ring-primary focus:border-primary transition-all duration-300">
                                <div class="text-sm text-gray-500 mt-1">分钟</div>
                            </div>
                            <div class="text-center">
                                <input type="number" id="timer-seconds" min="0" max="59" value="0" class="w-20 h-20 text-4xl font-bold text-center border border-gray-300 rounded-lg focus:ring-2 focus:ring-primary focus:border-primary transition-all duration-300">
                                <div class="text-sm text-gray-500 mt-1">秒</div>
                            </div>
                        </div>
                        
                        <!-- 计时器显示 (默认隐藏) -->
                        <div id="timer-display-container" class="hidden mb-8 relative w-64 h-64 flex items-center justify-center">
                            <div id="timer-display" class="text-[clamp(2.5rem,5vw,4rem)] font-bold text-dark tracking-wider">
                                00:00:00
                            </div>
                            <div id="timer-progress" class="absolute inset-0 rounded-full timer-circle" style="--progress: 0%"></div>
                        </div>
                        
                        <div class="flex gap-4 mt-4">
                            <button id="start-timer" class="bg-primary text-white px-6 py-3 rounded-lg hover:bg-primary/90 transition-all duration-300 flex items-center">
                                <i class="fa fa-play mr-2"></i> 开始
                            </button>
                            <button id="stop-timer" class="bg-gray-200 text-gray-700 px-6 py-3 rounded-lg hover:bg-gray-300 transition-all duration-300 flex items-center" disabled>
                                <i class="fa fa-pause mr-2"></i> 停止
                            </button>
                            <button id="reset-timer" class="bg-gray-200 text-gray-700 px-6 py-3 rounded-lg hover:bg-gray-300 transition-all duration-300 flex items-center" disabled>
                                <i class="fa fa-refresh mr-2"></i> 重置
                            </button>
                        </div>
                    </div>
                </div>
                
                <div class="bg-white rounded-2xl p-6 clock-shadow">
                    <h2 class="text-xl font-bold text-dark mb-4">计时器设置</h2>
                    <div class="space-y-4">
                        <div>
                            <label for="timer-sound" class="block text-sm font-medium text-gray-700 mb-1">计时结束提示音</label>
                            <input type="text" id="timer-sound" placeholder="输入音乐链接" class="w-full p-3 rounded-lg border border-gray-300 focus:ring-2 focus:ring-primary focus:border-primary transition-all duration-300" value="/铃声.mp3">
                            <p class="text-xs text-gray-500 mt-1">请输入有效的音乐链接，例如: https://example.com/alarm.mp3</p>
                        </div>
                    </div>
                </div>
            </section>
        </main>
        
        <!-- 页脚 -->
        <footer class="mt-12 text-center text-gray-500">
            <p>多功能时钟应用 &copy; <?php echo date('Y'); ?></p>
        </footer>
    </div>
    
    <!-- 闹钟提醒模态框 -->
    <div id="alarm-modal" class="fixed inset-0 bg-black/50 flex items-center justify-center z-50 hidden">
        <div class="bg-white rounded-2xl p-8 max-w-md w-full mx-4 transform transition-all duration-300 scale-95 opacity-0" id="modal-content">
            <div class="text-center">
                <div id="alarm-icon" class="text-primary text-6xl mb-4">
                    <i class="fa fa-bell-o"></i>
                </div>
                <h3 class="text-2xl font-bold text-dark mb-2" id="alarm-title">闹钟时间到</h3>
                <p class="text-gray-500 mb-6" id="alarm-message">您设置的闹钟已触发</p>
                <div class="flex justify-center gap-4">
                    <button id="dismiss-alarm" class="bg-primary text-white px-6 py-3 rounded-lg hover:bg-primary/90 transition-all duration-300">
                        关闭闹钟
                    </button>
                    <button id="snooze-alarm" class="bg-gray-200 text-gray-700 px-6 py-3 rounded-lg hover:bg-gray-300 transition-all duration-300">
                        <i class="fa fa-clock-o mr-2"></i> 稍后提醒
                    </button>
                </div>
            </div>
        </div>
    </div>
    
    <!-- 计时器结束提示模态框 -->
    <div id="timer-modal" class="fixed inset-0 bg-black/50 flex items-center justify-center z-50 hidden">
        <div class="bg-white rounded-2xl p-8 max-w-md w-full mx-4 transform transition-all duration-300 scale-95 opacity-0" id="timer-modal-content">
            <div class="text-center">
                <div id="timer-icon" class="text-secondary text-6xl mb-4">
                    <i class="fa fa-hourglass-end"></i>
                </div>
                <h3 class="text-2xl font-bold text-dark mb-2">计时结束</h3>
                <p class="text-gray-500 mb-6">您设置的计时器已完成</p>
                <div class="flex justify-center gap-4">
                    <button id="dismiss-timer" class="bg-secondary text-white px-6 py-3 rounded-lg hover:bg-secondary/90 transition-all duration-300">
                        关闭提示
                    </button>
                </div>
            </div>
        </div>
    </div>
    
    <!-- 音频元素 -->
    <audio id="alarm-sound-element" preload="auto"></audio>
    <audio id="timer-sound-element" preload="auto"></audio>
    
    <script>
        // 全局变量
        let stopwatchInterval = null;
        let stopwatchTime = 0;
        let timerInterval = null;
        let timerTime = 0;
        let timerTotalSeconds = 0;
        let currentActiveAlarm = null;
        let isAudioInitialized = false;
        let activeAlarms = []; // 存储已触发的闹钟，防止重复触发
        let snoozeTimeout = null; // 稍后提醒计时器
        
        // DOM 加载完成后执行
        document.addEventListener('DOMContentLoaded', function() {
            // 初始化当前时间显示
            updateCurrentTime();
            setInterval(updateCurrentTime, 1000);
            
            // 初始化音频（在用户交互后）
            document.addEventListener('click', initializeAudio, { once: true });
            
            // 导航按钮切换
            document.querySelectorAll('.nav-btn').forEach(btn => {
                btn.addEventListener('click', function() {
                    // 移除所有活动状态
                    document.querySelectorAll('.nav-btn').forEach(b => {
                        b.classList.remove('active', 'bg-primary', 'text-white', 'shadow-lg');
                        b.classList.add('bg-white', 'text-dark', 'shadow-md');
                    });
                    
                    // 添加当前按钮活动状态
                    this.classList.add('active', 'bg-primary', 'text-white', 'shadow-lg');
                    this.classList.remove('bg-white', 'text-dark', 'shadow-md');
                    
                    // 隐藏所有内容区域
                    document.querySelectorAll('main > section').forEach(section => {
                        section.classList.add('hidden');
                        section.classList.remove('active');
                    });
                    
                    // 显示对应内容区域
                    const sectionId = this.id.replace('nav-', '') + '-section';
                    document.getElementById(sectionId).classList.remove('hidden');
                    document.getElementById(sectionId).classList.add('active');
                });
            });
            
            // 添加闹钟按钮
            document.getElementById('add-alarm-btn').addEventListener('click', function() {
                document.getElementById('alarm-section').classList.add('hidden');
                document.getElementById('add-alarm-section').classList.remove('hidden');
            });
            
            // 返回闹钟列表按钮
            document.getElementById('back-to-alarms-btn').addEventListener('click', function() {
                document.getElementById('add-alarm-section').classList.add('hidden');
                document.getElementById('alarm-section').classList.remove('hidden');
            });
            
            // 删除闹钟按钮
            document.querySelectorAll('.delete-alarm-btn').forEach(btn => {
                btn.addEventListener('click', function() {
                    const index = this.getAttribute('data-index');
                    if (confirm('确定要删除这个闹钟吗？')) {
                        window.location.href = 'index.php?delete_alarm=' + index;
                    }
                });
            });
            
            // 秒表控制按钮
            document.getElementById('start-stopwatch').addEventListener('click', startStopwatch);
            document.getElementById('stop-stopwatch').addEventListener('click', stopStopwatch);
            document.getElementById('reset-stopwatch').addEventListener('click', resetStopwatch);
            document.getElementById('lap-stopwatch').addEventListener('click', lapStopwatch);
            
            // 计时器控制按钮
            document.getElementById('start-timer').addEventListener('click', startTimer);
            document.getElementById('stop-timer').addEventListener('click', stopTimer);
            document.getElementById('reset-timer').addEventListener('click', resetTimer);
            
            // 模态框关闭按钮
            document.getElementById('dismiss-alarm').addEventListener('click', dismissAlarm);
            document.getElementById('dismiss-timer').addEventListener('click', dismissTimer);
            document.getElementById('snooze-alarm').addEventListener('click', snoozeAlarm);
            
            // 检查闹钟 - 每秒检查一次，提高触发准确性
            checkAlarms();
            setInterval(checkAlarms, 1000);
        });
        
        // 初始化音频（在用户首次交互后）
        function initializeAudio() {
            if (isAudioInitialized) return;
            
            // 预加载静音音频
            const testAudio = new Audio('data:audio/wav;base64,UklGRigAAABXQVZFZm10IBAAAAABAAEARKwAAIhYAQACABAAZGF0YQAAAAA=');
            testAudio.play().then(() => {
                isAudioInitialized = true;
                console.log('音频已初始化，可以播放');
            }).catch(e => {
                console.log('音频初始化失败:', e);
            });
        }
        
        // 更新当前时间显示
        function updateCurrentTime() {
            const now = new Date();
            const hours = String(now.getHours()).padStart(2, '0');
            const minutes = String(now.getMinutes()).padStart(2, '0');
            const seconds = String(now.getSeconds()).padStart(2, '0');
            const days = ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六'];
            const dayOfWeek = days[now.getDay()];
            const year = now.getFullYear();
            const month = String(now.getMonth() + 1).padStart(2, '0');
            const date = String(now.getDate()).padStart(2, '0');
            
            document.getElementById('current-time').textContent = `${hours}:${minutes}:${seconds}`;
            document.getElementById('current-date').textContent = `${year}年${month}月${date}日 ${dayOfWeek}`;
        }
        
        // 检查闹钟
        function checkAlarms() {
            const now = new Date();
            const currentHours = now.getHours();
            const currentMinutes = now.getMinutes();
            const currentSeconds = now.getSeconds();
            const currentDate = now.toISOString().split('T')[0]; // 获取当前日期 YYYY-MM-DD
            
            // 获取所有闹钟
            const alarmItems = document.querySelectorAll('.alarm-item');
            
            alarmItems.forEach(item => {
                const timeElement = item.querySelector('.text-2xl');
                const alarmTimeStr = timeElement.textContent.trim();
                const [hours, minutes] = alarmTimeStr.split(':').map(Number);
                
                // 获取闹钟声音和标签
                const soundElement = item.querySelector('.text-sm');
                const sound = soundElement.textContent.replace('声音: ', '');
                
                const labelElement = item.querySelector('.font-medium');
                const label = labelElement.textContent;
                
                const index = item.getAttribute('data-index');
                
                // 如果是今天的闹钟，且时间匹配，触发闹钟
                if (currentHours === hours && currentMinutes === minutes && currentSeconds < 5) {
                    // 检查是否已经触发过
                    if (!activeAlarms.includes(index)) {
                        activeAlarms.push(index); // 标记为已触发
                        triggerAlarm(alarmTimeStr, sound, label, index);
                    }
                }
            });
        }
        
        // 触发闹钟
        function triggerAlarm(time, sound, label, index) {
            // 设置闹钟声音
            const audio = document.getElementById('alarm-sound-element');
            audio.src = sound;
            audio.loop = true;
            
            // 设置闹钟标题和消息
            document.getElementById('alarm-title').textContent = '闹钟时间到';
            document.getElementById('alarm-message').textContent = `标签: ${label}\n时间: ${time}`;
            
            // 显示闹钟图标动画
            const alarmIcon = document.getElementById('alarm-icon');
            alarmIcon.classList.add('alarm-ringing');
            
            // 记录当前活动闹钟
            currentActiveAlarm = index;
            
            // 显示模态框
            const modal = document.getElementById('alarm-modal');
            const modalContent = document.getElementById('modal-content');
            modal.classList.remove('hidden');
            
            // 添加动画
            setTimeout(() => {
                modalContent.classList.remove('scale-95', 'opacity-0');
                modalContent.classList.add('scale-100', 'opacity-100');
            }, 10);
            
            // 播放声音
            audio.play().catch(e => {
                console.log('无法自动播放音频:', e);
                // 提示用户点击以启用声音
                document.getElementById('alarm-message').textContent = '请点击页面以启用声音播放，然后点击"关闭闹钟"\n\n标签: ' + label;
            });
        }
        
        // 关闭闹钟
        function dismissAlarm() {
            const modal = document.getElementById('alarm-modal');
            const modalContent = document.getElementById('modal-content');
            const audio = document.getElementById('alarm-sound-element');
            const alarmIcon = document.getElementById('alarm-icon');
            
            // 停止动画
            alarmIcon.classList.remove('alarm-ringing');
            
            // 添加关闭动画
            modalContent.classList.remove('scale-100', 'opacity-100');
            modalContent.classList.add('scale-95', 'opacity-0');
            
            // 延迟隐藏模态框
            setTimeout(() => {
                modal.classList.add('hidden');
                audio.pause();
                audio.currentTime = 0;
                
                // 从已触发列表中移除
                if (currentActiveAlarm && activeAlarms.includes(currentActiveAlarm)) {
                    const index = activeAlarms.indexOf(currentActiveAlarm);
                    if (index !== -1) {
                        activeAlarms.splice(index, 1);
                    }
                }
                
                // 标记闹钟为已触发（在实际应用中，可能需要更新服务器上的闹钟状态）
                if (currentActiveAlarm !== null) {
                    // 这里只是示例，实际应用中可能需要通过AJAX请求更新服务器数据
                    console.log(`闹钟 ${currentActiveAlarm} 已触发`);
                    
                    // 更新闹钟项样式
                    const alarmItem = document.querySelector(`.alarm-item[data-index="${currentActiveAlarm}"]`);
                    if (alarmItem) {
                        alarmItem.classList.remove('border-l-4', 'border-primary');
                        alarmItem.classList.add('bg-gray-100', 'opacity-70');
                    }
                }
                
                currentActiveAlarm = null;
            }, 300);
        }
        
        // 稍后提醒
        function snoozeAlarm() {
            const audio = document.getElementById('alarm-sound-element');
            const alarmIcon = document.getElementById('alarm-icon');
            
            // 停止动画
            alarmIcon.classList.remove('alarm-ringing');
            
            // 停止播放声音
            audio.pause();
            audio.currentTime = 0;
            
            // 隐藏模态框
            const modal = document.getElementById('alarm-modal');
            const modalContent = document.getElementById('modal-content');
            modalContent.classList.remove('scale-100', 'opacity-100');
            modalContent.classList.add('scale-95', 'opacity-0');
            
            setTimeout(() => {
                modal.classList.add('hidden');
            }, 300);
            
            // 设置5分钟后再次提醒
            if (currentActiveAlarm !== null) {
                // 从已触发列表中移除，允许再次触发
                const index = activeAlarms.indexOf(currentActiveAlarm);
                if (index !== -1) {
                    activeAlarms.splice(index, 1);
                }
                
                // 获取当前闹钟信息
                const alarmItem = document.querySelector(`.alarm-item[data-index="${currentActiveAlarm}"]`);
                if (alarmItem) {
                    const timeElement = alarmItem.querySelector('.text-2xl');
                    const alarmTimeStr = timeElement.textContent.trim();
                    
                    const soundElement = alarmItem.querySelector('.text-sm');
                    const sound = soundElement.textContent.replace('声音: ', '');
                    
                    const labelElement = alarmItem.querySelector('.font-medium');
                    const label = labelElement.textContent;
                    
                    // 设置稍后提醒定时器
                    if (snoozeTimeout) {
                        clearTimeout(snoozeTimeout);
                    }
                    
                    // 5分钟后再次触发
                    snoozeTimeout = setTimeout(() => {
                        triggerAlarm(alarmTimeStr, sound, label, currentActiveAlarm);
                    }, 5 * 60 * 1000);
                }
            }
        }
        
        // 开始秒表
        function startStopwatch() {
            // 更新按钮状态
            document.getElementById('start-stopwatch').disabled = true;
            document.getElementById('stop-stopwatch').disabled = false;
            document.getElementById('reset-stopwatch').disabled = false;
            document.getElementById('lap-stopwatch').disabled = false;
            
            // 更新按钮样式
            document.getElementById('start-stopwatch').classList.add('bg-gray-200', 'text-gray-700');
            document.getElementById('start-stopwatch').classList.remove('bg-primary', 'text-white');
            document.getElementById('stop-stopwatch').classList.add('bg-primary', 'text-white');
            document.getElementById('stop-stopwatch').classList.remove('bg-gray-200', 'text-gray-700');
            
            // 开始计时
            stopwatchInterval = setInterval(() => {
                stopwatchTime++;
                updateStopwatchDisplay();
            }, 100);
        }
        
        // 停止秒表
        function stopStopwatch() {
            // 更新按钮状态
            document.getElementById('start-stopwatch').disabled = false;
            document.getElementById('stop-stopwatch').disabled = true;
            document.getElementById('lap-stopwatch').disabled = true;
            
            // 更新按钮样式
            document.getElementById('start-stopwatch').classList.remove('bg-gray-200', 'text-gray-700');
            document.getElementById('start-stopwatch').classList.add('bg-primary', 'text-white');
            document.getElementById('stop-stopwatch').classList.remove('bg-primary', 'text-white');
            document.getElementById('stop-stopwatch').classList.add('bg-gray-200', 'text-gray-700');
            
            // 停止计时
            clearInterval(stopwatchInterval);
        }
        
        // 重置秒表
        function resetStopwatch() {
            // 更新按钮状态
            document.getElementById('reset-stopwatch').disabled = true;
            document.getElementById('lap-stopwatch').disabled = true;
            
            // 停止计时
            clearInterval(stopwatchInterval);
            
            // 重置时间
            stopwatchTime = 0;
            updateStopwatchDisplay();
            
            // 清空计次记录
            document.getElementById('stopwatch-laps').innerHTML = `
                <div class="text-center py-8 text-gray-500">
                    <i class="fa fa-clock-o text-4xl mb-4"></i>
                    <p>暂无计时记录</p>
                </div>
            `;
            
            // 重置按钮样式
            document.getElementById('start-stopwatch').disabled = false;
            document.getElementById('stop-stopwatch').disabled = true;
            document.getElementById('start-stopwatch').classList.remove('bg-gray-200', 'text-gray-700');
            document.getElementById('start-stopwatch').classList.add('bg-primary', 'text-white');
            document.getElementById('stop-stopwatch').classList.remove('bg-primary', 'text-white');
            document.getElementById('stop-stopwatch').classList.add('bg-gray-200', 'text-gray-700');
        }
        
        // 更新秒表显示
        function updateStopwatchDisplay() {
            const hours = Math.floor(stopwatchTime / 36000);
            const minutes = Math.floor((stopwatchTime % 36000) / 600);
            const seconds = Math.floor((stopwatchTime % 600) / 10);
            const centiseconds = stopwatchTime % 10;
            
            const display = `${String(hours).padStart(2, '0')}:${String(minutes).padStart(2, '0')}:${String(seconds).padStart(2, '0')}.${centiseconds}`;
            document.getElementById('stopwatch-display').textContent = display;
            
            // 添加数字变化动画
            const digits = document.getElementById('stopwatch-display').textContent.split('');
            digits.forEach((digit, index) => {
                const digitElement = document.getElementById(`stopwatch-digit-${index}`);
                if (digitElement) {
                    digitElement.classList.add('stopwatch-digit');
                    setTimeout(() => {
                        digitElement.classList.remove('stopwatch-digit');
                    }, 200);
                }
            });
        }
        
        // 秒表计次
        function lapStopwatch() {
            const lapsContainer = document.getElementById('stopwatch-laps');
            const hours = Math.floor(stopwatchTime / 36000);
            const minutes = Math.floor((stopwatchTime % 36000) / 600);
            const seconds = Math.floor((stopwatchTime % 600) / 10);
            const centiseconds = stopwatchTime % 10;
            
            const lapTime = `${String(hours).padStart(2, '0')}:${String(minutes).padStart(2, '0')}:${String(seconds).padStart(2, '0')}.${centiseconds}`;
            
            // 检查是否是第一条记录
            if (lapsContainer.innerHTML.includes('暂无计时记录')) {
                lapsContainer.innerHTML = '';
            }
            
            // 创建新的计次记录
            const lapItem = document.createElement('div');
            lapItem.className = 'flex justify-between p-3 border-b border-gray-100 hover:bg-gray-50 transition-colors';
            
            // 获取当前计次数量
            const lapCount = lapsContainer.children.length + 1;
            
            // 设置计次内容
            lapItem.innerHTML = `
                <div class="text-gray-500">计次 ${lapCount}</div>
                <div class="font-medium">${lapTime}</div>
            `;
            
            // 添加到顶部
            lapsContainer.insertBefore(lapItem, lapsContainer.firstChild);
        }
        
        // 开始计时器
        function startTimer() {
            // 获取设置的时间
            const hours = parseInt(document.getElementById('timer-hours').value) || 0;
            const minutes = parseInt(document.getElementById('timer-minutes').value) || 0;
            const seconds = parseInt(document.getElementById('timer-seconds').value) || 0;
            
            // 计算总秒数
            timerTotalSeconds = hours * 3600 + minutes * 60 + seconds;
            
            // 检查是否有设置时间
            if (timerTotalSeconds <= 0) {
                alert('请设置计时器时间');
                return;
            }
            
            // 隐藏设置，显示计时器
            document.getElementById('timer-settings').classList.add('hidden');
            document.getElementById('timer-display-container').classList.remove('hidden');
            
            // 更新按钮状态
            document.getElementById('start-timer').disabled = true;
            document.getElementById('stop-timer').disabled = false;
            document.getElementById('reset-timer').disabled = false;
            
            // 更新按钮样式
            document.getElementById('start-timer').classList.add('bg-gray-200', 'text-gray-700');
            document.getElementById('start-timer').classList.remove('bg-primary', 'text-white');
            document.getElementById('stop-timer').classList.add('bg-primary', 'text-white');
            document.getElementById('stop-timer').classList.remove('bg-gray-200', 'text-gray-700');
            
            // 初始化计时器
            timerTime = timerTotalSeconds;
            updateTimerDisplay();
            
            // 开始计时
            timerInterval = setInterval(() => {
                timerTime--;
                updateTimerDisplay();
                
                // 检查是否计时结束
                if (timerTime <= 0) {
                    clearInterval(timerInterval);
                    triggerTimerEnd();
                }
            }, 1000);
        }
        
        // 停止计时器
        function stopTimer() {
            // 更新按钮状态
            document.getElementById('start-timer').disabled = false;
            document.getElementById('stop-timer').disabled = true;
            
            // 更新按钮样式
            document.getElementById('start-timer').classList.remove('bg-gray-200', 'text-gray-700');
            document.getElementById('start-timer').classList.add('bg-primary', 'text-white');
            document.getElementById('stop-timer').classList.remove('bg-primary', 'text-white');
            document.getElementById('stop-timer').classList.add('bg-gray-200', 'text-gray-700');
            
            // 停止计时
            clearInterval(timerInterval);
        }
        
        // 重置计时器
        function resetTimer() {
            // 更新按钮状态
            document.getElementById('start-timer').disabled = false;
            document.getElementById('stop-timer').disabled = true;
            document.getElementById('reset-timer').disabled = true;
            
            // 停止计时
            clearInterval(timerInterval);
            
            // 重置时间
            timerTime = 0;
            document.getElementById('timer-hours').value = 0;
            document.getElementById('timer-minutes').value = 0;
            document.getElementById('timer-seconds').value = 0;
            
            // 隐藏计时器，显示设置
            document.getElementById('timer-display-container').classList.add('hidden');
            document.getElementById('timer-settings').classList.remove('hidden');
            
            // 重置按钮样式
            document.getElementById('start-timer').classList.remove('bg-gray-200', 'text-gray-700');
            document.getElementById('start-timer').classList.add('bg-primary', 'text-white');
            document.getElementById('stop-timer').classList.remove('bg-primary', 'text-white');
            document.getElementById('stop-timer').classList.add('bg-gray-200', 'text-gray-700');
        }
        
        // 更新计时器显示
        function updateTimerDisplay() {
            const hours = Math.floor(timerTime / 3600);
            const minutes = Math.floor((timerTime % 3600) / 60);
            const seconds = timerTime % 60;
            
            const display = `${String(hours).padStart(2, '0')}:${String(minutes).padStart(2, '0')}:${String(seconds).padStart(2, '0')}`;
            document.getElementById('timer-display').textContent = display;
            
            // 更新进度环
            const progress = (1 - (timerTime / timerTotalSeconds)) * 100;
            document.getElementById('timer-progress').style.setProperty('--progress', `${progress}%`);
            
            // 当剩余时间小于10秒时添加脉冲动画
            if (timerTime <= 10) {
                document.getElementById('timer-display').classList.add('timer-pulse');
                document.getElementById('timer-progress').classList.add('alarm-pulse');
            } else {
                document.getElementById('timer-display').classList.remove('timer-pulse');
                document.getElementById('timer-progress').classList.remove('alarm-pulse');
            }
        }
        
        // 触发计时器结束
        function triggerTimerEnd() {
            // 设置计时器声音
            const audio = document.getElementById('timer-sound-element');
            audio.src = document.getElementById('timer-sound').value || '/铃声.mp3';
            audio.loop = true;
            
            // 显示计时器图标动画
            const timerIcon = document.getElementById('timer-icon');
            timerIcon.classList.add('alarm-ringing');
            
            // 显示模态框
            const modal = document.getElementById('timer-modal');
            const modalContent = document.getElementById('timer-modal-content');
            modal.classList.remove('hidden');
            
            // 添加动画
            setTimeout(() => {
                modalContent.classList.remove('scale-95', 'opacity-0');
                modalContent.classList.add('scale-100', 'opacity-100');
            }, 10);
            
            // 播放声音
            audio.play().catch(e => {
                console.log('无法自动播放音频:', e);
                // 提示用户点击以启用声音
                document.querySelector('#timer-modal-content p').textContent = '请点击页面以启用声音播放，然后点击"关闭提示"';
            });
        }
        
        // 关闭计时器提示
        function dismissTimer() {
            const modal = document.getElementById('timer-modal');
            const modalContent = document.getElementById('timer-modal-content');
            const audio = document.getElementById('timer-sound-element');
            const timerIcon = document.getElementById('timer-icon');
            
            // 停止动画
            timerIcon.classList.remove('alarm-ringing');
            
            // 添加关闭动画
            modalContent.classList.remove('scale-100', 'opacity-100');
            modalContent.classList.add('scale-95', 'opacity-0');
            
            // 延迟隐藏模态框
            setTimeout(() => {
                modal.classList.add('hidden');
                audio.pause();
                audio.currentTime = 0;
                
                // 重置计时器
                resetTimer();
            }, 300);
        }
        
        // 表单提交验证
        document.getElementById('add-alarm-form').addEventListener('submit', function(e) {
            const timeInput = document.getElementById('alarm-time');
            const labelInput = document.getElementById('alarm-label');
            const soundInput = document.getElementById('alarm-sound');
            
            if (!timeInput.value || !labelInput.value || !soundInput.value) {
                alert('请填写所有字段');
                e.preventDefault();
                return false;
            }
            
            
            return true;
        });
        
        // 数字输入框限制
        document.getElementById('timer-hours').addEventListener('change', function() {
            if (this.value > 23) this.value = 23;
            if (this.value < 0) this.value = 0;
        });
        
        document.getElementById('timer-minutes').addEventListener('change', function() {
            if (this.value > 59) this.value = 59;
            if (this.value < 0) this.value = 0;
        });
        
        document.getElementById('timer-seconds').addEventListener('change', function() {
            if (this.value > 59) this.value = 59;
            if (this.value < 0) this.value = 0;
        });
        
        // 模态框点击外部关闭
        document.getElementById('alarm-modal').addEventListener('click', function(e) {
            if (e.target === this) {
                dismissAlarm();
            }
        });
        
        document.getElementById('timer-modal').addEventListener('click', function(e) {
            if (e.target === this) {
                dismissTimer();
            }
        });
    </script>
</body>
</html>